==> haskell-blaze-markup-0.7.1.1-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-blaze-markup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-markup
version: 0.7.1.1
id: blaze-markup-0.7.1.1-Amik95gvtJH76XeEGEdOV0
key: blaze-markup-0.7.1.1-Amik95gvtJH76XeEGEdOV0
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
stability: Experimental
homepage: http://jaspervdj.be/blaze
synopsis: A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.
category: Text
author: Jasper Van der Jeugt, Simon Meier, Deepak Jois
exposed: True
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8
abi: 270133949e13564cf8f299f9ac313bda
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/blaze-markup-0.7.1.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/blaze-markup-0.7.1.1
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/blaze-markup-0.7.1.1
hs-libraries: HSblaze-markup-0.7.1.1-Amik95gvtJH76XeEGEdOV0
depends:
    base-4.9.1.0 blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO
    bytestring-0.10.8.1 text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
haddock-interfaces: /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock
haddock-html: /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-markup-0.8.0.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-blaze-markup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-markup
version: 0.8.0.0
id: blaze-markup-0.8.0.0-6wPbGvG5gVcIJK8r30JWLy
key: blaze-markup-0.8.0.0-6wPbGvG5gVcIJK8r30JWLy
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
stability: Experimental
homepage: http://jaspervdj.be/blaze
synopsis: A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.
category: Text
author: Jasper Van der Jeugt, Simon Meier, Deepak Jois
exposed: True
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8
abi: 521d14bbfd25bbec5f627ee6d61d1bbc
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/blaze-markup-0.8.0.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/blaze-markup-0.8.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/blaze-markup-0.8.0.0
hs-libraries: HSblaze-markup-0.8.0.0-6wPbGvG5gVcIJK8r30JWLy
depends:
    base-4.9.1.0 blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO
    bytestring-0.10.8.1 text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
haddock-interfaces: /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock
haddock-html: /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
